# copyright <sebas @ koumbit.org>
# Licence: GPL
#

class di_netboot_assistant {

   package { [ "di-netboot-assistant" ]: ensure => installed }

   # sources.list with the lastest Ubuntu releases
   file { "/etc/di-netboot-assistant/di-sources.list":
      owner => root,
      group => root,
      mode => 644,
      source => "puppet:///di_netboot_assistant/di-sources.list"
   }

   # some customization of the pxe menu
   file { "/etc/di-netboot-assistant/pxelinux.HEAD":
      owner => root,
      group => root,
      mode => 644,
      source => "puppet:///di_netboot_assistant/pxelinux.HEAD"
   }

   # symbolic link to generated menu
   file  { "/var/lib/tftpboot/pxelinux.cfg/default":
      ensure => "../debian-installer/pxelinux.cfg/default"
   }

   exec { "di_netboot_assistant_lenny":
      command => "di-netboot-assistant install lenny --arch=amd64,i386 &>/dev/null",
      creates => "/var/lib/tftpboot/debian-installer/lenny/i386/linux",
      path => "/bin:/sbin:/usr/sbin:/usr/bin",
      require => [Package["di-netboot-assistant"], File["/etc/di-netboot-assistant/di-sources.list"], File["/etc/di-netboot-assistant/pxelinux.HEAD"]]
   }

   exec { "di_netboot_assistant_hardy":
      command => "di-netboot-assistant install hardy --arch=amd64,i386 &>/dev/null",
      creates => "/var/lib/tftpboot/debian-installer/hardy/i386/linux",
      path => "/bin:/sbin:/usr/sbin:/usr/bin",
      require => [Package["di-netboot-assistant"], exec["di_netboot_assistant_lenny"]]
   }

   exec { "di_netboot_assistant_jaunty":
      command => "di-netboot-assistant install jaunty --arch=amd64,i386 &>/dev/null",
      creates => "/var/lib/tftpboot/debian-installer/jaunty/i386/linux",
      path => "/bin:/sbin:/usr/sbin:/usr/bin",
      require => [Package["di-netboot-assistant"], exec["di_netboot_assistant_lenny"]]
   }
}

class di_netboot_assistant::debian::powerpc::daily {

    package { [ "tftpd-hpa" ]: ensure => installed }

    file { ["/var/lib/tftpboot/debian-installer", "/var/lib/tftpboot/debian-installer/daily", "/var/lib/tftpboot/debian-installer/daily/powerpc/"]:
      ensure => directory,
      owner => root,
      group => root,
      require => Package["tftpd-hpa"];
    }

   fetch_netboot_powerpc { [ "boot.msg", "initrd.gz", "vmlinux", "yaboot", "yaboot.conf" ]:  }

   $mirror_daily_di = "http://d-i.debian.org/daily-images/powerpc/daily/powerpc/netboot"

   define fetch_netboot_powerpc($mirror = "http://d-i.debian.org/daily-images/powerpc/daily/powerpc/netboot") {

#   file { ["/var/lib/tftpboot/debian-installer/daily1", "/var/lib/tftpboot/debian-installer/daily1/powerpc/"]:
#      ensure => directory,
#      owner => root,
#      group => root,
#      require => [Package["tftpd-hpa"]];
#    }

    exec { "wget -O /var/lib/tftpboot/debian-installer/daily/powerpc/$name -q $mirror1/$name":
      creates => "/var/lib/tftpboot/debian-installer/daily/powerpc/$name",
      path => "/usr/bin",
      require => [Package["tftpd-hpa"], File["/var/lib/tftpboot/debian-installer/daily/powerpc/"]]
    }
   }
}

class di_netboot_assistant::debian::powerpc::squeeze {

    file { ["/var/lib/tftpboot/debian-installer/squeeze", "/var/lib/tftpboot/debian-installer/squeeze/powerpc/"]:
      ensure => directory,
      owner => root,
      group => root,
      require => Package["tftpd-hpa"];
    }

   fetch_netboot_powerpc_squeeze { [ "boot.msg", "initrd.gz", "vmlinux", "yaboot", "yaboot.conf" ]:  }

   define fetch_netboot_powerpc_squeeze($mirror = "http://debian.torredehanoi.org/debian/dists/squeeze/main/installer-powerpc/current/images/powerpc/netboot") {

   exec { "wget -O /var/lib/tftpboot/debian-installer/squeeze/powerpc/$name -q $mirro1/$name":
     creates => "/var/lib/tftpboot/debian-installer/squeeze/powerpc/$name",
     path => "/usr/bin",
     require => [Package["tftpd-hpa"], File["/var/lib/tftpboot/debian-installer/squeeze/powerpc/"]]
   }
  }
}
